import{r as o,M as i,uo as t,up as r,ax as s,uq as v,ur as a,us as c}from"./index-DCfAVbXp.js";function l({children:n}){const{i18n:p}=i(),e=p.dir(),x=o.useMemo(()=>t({...r,direction:e,shadows:{...r.shadows,selected:"inset 0px 0px 0px 3px var(--invoke-colors-invokeBlue-500), inset 0px 0px 0px 4px var(--invoke-colors-invokeBlue-800)",hoverSelected:"inset 0px 0px 0px 3px var(--invoke-colors-invokeBlue-400), inset 0px 0px 0px 4px var(--invoke-colors-invokeBlue-800)",hoverUnselected:"inset 0px 0px 0px 2px var(--invoke-colors-invokeBlue-300), inset 0px 0px 0px 3px var(--invoke-colors-invokeBlue-800)",selectedForCompare:"inset 0px 0px 0px 3px var(--invoke-colors-invokeGreen-300), inset 0px 0px 0px 4px var(--invoke-colors-invokeGreen-800)",hoverSelectedForCompare:"inset 0px 0px 0px 3px var(--invoke-colors-invokeGreen-200), inset 0px 0px 0px 4px var(--invoke-colors-invokeGreen-800)"}}),[e]);return o.useEffect(()=>{document.body.dir=e},[e]),s.jsx(v,{theme:x,toastOptions:a,children:s.jsx(c,{children:n})})}const u=o.memo(l);export{u as default};
